==> igniteui-webcomponents-layouts-4.7.2-beta.0.tgz: package/esm2015/lib/igc-tool-action-separator-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionSeparatorComponent = /*@__PURE__*/ (() => {
    class IgcToolActionSeparatorComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionSeparator();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                let names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        }
        static register() {
            if (!IgcToolActionSeparatorComponent._isElementRegistered) {
                IgcToolActionSeparatorComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
            }
        }
        /**
         * Gets or sets the size of the separator.
        */
        get size() {
            return this.i.e9;
        }
        set size(v) {
            this.i.e9 = +v;
            this._a("size", this.i.e9);
        }
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get isGroupHeaderSeparator() {
            return this.i.e7;
        }
        set isGroupHeaderSeparator(v) {
            this.i.e7 = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.e7);
        }
        fromInfo(info) {
            this.i.dt(info);
        }
    }
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
})();

==> igniteui-webcomponents-layouts-4.8.1-beta.0.tgz: package/esm2015/lib/igc-tool-action-separator-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionSeparatorComponent = /*@__PURE__*/ (() => {
    class IgcToolActionSeparatorComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionSeparator();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                let names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        }
        static register() {
            if (!IgcToolActionSeparatorComponent._isElementRegistered) {
                IgcToolActionSeparatorComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
            }
        }
        /**
         * Gets or sets the size of the separator.
        */
        get size() {
            return this.i.f9;
        }
        set size(v) {
            this.i.f9 = +v;
            this._a("size", this.i.f9);
        }
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get isGroupHeaderSeparator() {
            return this.i.f7;
        }
        set isGroupHeaderSeparator(v) {
            this.i.f7 = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.f7);
        }
        fromInfo(info) {
            this.i.ej(info);
        }
    }
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
})();
